==> apache-log4j-2.21.1-src.zip: log4j-api-test/src/test/java/org/apache/logging/log4j/util/SystemPropertiesMain.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.util;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Enumeration;
import java.util.List;

/**
 * Prints system properties to the console.
 */
public class SystemPropertiesMain {

    /**
     * Prints system properties to the console.
     *
     * @param args
     *            unused
     */
    public static void main(final String[] args) {
        @SuppressWarnings("unchecked")
        final
        Enumeration<String> keyEnum = (Enumeration<String>) System.getProperties().propertyNames();
        final List<String> list = new ArrayList<>();
        while (keyEnum.hasMoreElements()) {
            list.add(keyEnum.nextElement());
        }
        Collections.sort(list);
        for (final String key : list) {
            System.out.println(key + " = " + System.getProperty(key));
        }
    }
}

==> apache-log4j-2.25.3-src.zip: log4j-api-test/src/test/java/org/apache/logging/log4j/util/SystemPropertiesMain.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.util;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Enumeration;
import java.util.List;

/**
 * Prints system properties to the console.
 */
public class SystemPropertiesMain {

    /**
     * Prints system properties to the console.
     *
     * @param args
     *            unused
     */
    public static void main(final String[] args) {
        @SuppressWarnings("unchecked")
        final Enumeration<String> keyEnum =
                (Enumeration<String>) System.getProperties().propertyNames();
        final List<String> list = new ArrayList<>();
        while (keyEnum.hasMoreElements()) {
            list.add(keyEnum.nextElement());
        }
        Collections.sort(list);
        for (final String key : list) {
            System.out.println(key + " = " + System.getProperty(key));
        }
    }
}
